@@ -22,8 +22,12 @@ def acq_parameters(ns, rec_dis, offsetx, depth, dh, sdo, acq_type):
     --------
         src_loc: float32
             Location of sources
-        rec-loc: float32
+        rec_loc: float32
             Location of receivers
+        n_surface_rec: int
+            Number of receivers at the surface
+        n_well_rec: int
+            Number of receivers in wells at each side of the model
     """
     if rec_dis < dh:
         raise Exception("Receiver distance should be larger than spatial sampling")
@@ -323,7 +327,7 @@ def seismic_section(seismo, components=0, shape='3d'):
         data['taux'] = (seismo['taux'] + seismo['tauz']) / 2
         data['tauz'] = (seismo['taux'] + seismo['tauz']) / 2
     if shape == '2d':
-        (nt, nx, ns) = data[[*data][0]].shape
+        (nt, nr, ns) = data[[*data][0]].shape
         for par in data:
-            data[par] = np.reshape(data[par], (nt, nx * ns), 'F')
+            data[par] = np.reshape(data[par], (nt, nr * ns), 'F')
     return data
\ No newline at end of file
