@@ -60,6 +60,28 @@ def earth_model(model, keys=[],offset=None, depth= None, **kwargs):
     
 
 def seismic_section(ax, data, x_axis=None, t_axis=None, aspect_preserving=False, **kargs):
+    """
+    seismic_section show seismic section
+
+
+    Parameters
+    ----------
+    ax : Axes or array of Axes
+        ax to arrange plots
+    data : float
+        Seismic section
+    x_axis : array
+        X-axis, by default None
+    t_axis : array, optional
+        t-axis, by default None
+    aspect_preserving : bool, optional
+        _description_, by default False
+
+    Returns
+    -------
+    ax : Axis
+        The ax for more adjustment
+    """
     if aspect_preserving:
         aspect = (data.shape[0]/data.shape[1])
         ax.set_aspect(aspect)
@@ -70,7 +92,7 @@ def seismic_section(ax, data, x_axis=None, t_axis=None, aspect_preserving=False,
     if t_axis is None:
         t_axis = np.arange(data.shape[0])
 
-    im = ax.pcolor(x_axis, t_axis, data,  cmap='gray', shading='nearest', **kargs)
+    im = ax.pcolor(x_axis, t_axis, data,  cmap='gray', **kargs)
 
     ax.invert_yaxis()
     ax.axis([0, x_axis[-1], t_axis[-1], 0])
